bl_info = {
    "name": "MaSzyna T3D model exporter",
    "description": "Addon for exporting models to MaSzyna T3D text format",
    "author": "Krzysztof Przybyla (krzysiuup), Grzegorz Firlejczyk (firleju)",
    "version": (1, 0, 0),
    "blender": (2, 78, 0),
    "location": "File > Export",
    "wiki_url": "https://wiki.eu07.pl/index.php/Blender_-_modelowanie",
    "support": "OFFICIAL",
    "category": "Import-Export",
}

from collections import namedtuple

import bpy
from bpy.props import StringProperty, BoolProperty
from bpy_extras.io_utils import ExportHelper

from .src.exporter_builder import ExporterBuilder


class ExportT3D(bpy.types.Operator, ExportHelper):
    """ Save model in MaSzyna Train Simulator T3D text format """
    bl_idname = "export_model.t3d"
    bl_label = "Export T3D"
    filename_ext = ".t3d"

    bl_options = {'PRESET'}
    filter_glob = StringProperty(
        default="*.t3d",
        options={'HIDDEN'}
    )
    use_selection = BoolProperty(
        name="Selection Only",
        description="Export only selected objects",
        default=False
    )
    save_animations = BoolProperty(
        name="Export animations",
        description="Save animations as events in INC file",
        default=False
    )

    def execute(self, context):
        Config = namedtuple(
            "Config", "output_filepath objects_to_save save_animations"
        )

        objects_to_save = \
            bpy.context.selected_objects if self.use_selection \
            else bpy.context.visible_objects

        config = Config(
            self.filepath,
            objects_to_save,
            self.save_animations
        )

        exporter_builder = ExporterBuilder()
        main_exporter = exporter_builder.get_exporter()
        main_exporter.export_objects(config)

        return {'FINISHED'}


class AddonPreferences(bpy.types.AddonPreferences):
    bl_idname = __name__

    root_path = StringProperty(
        name="MaSzyna root",
        description="Path to MaSzyna root (main directory)",
        default="",
        subtype='DIR_PATH'
    )

    def draw(self, context):
        self.layout.label(text="User preferences")
        self.layout.prop(self, "root_path")


class AddonPropertiesOperator(bpy.types.Operator):
    bl_idname = "object.addon_prefs"
    bl_label = "Add-on Preferences"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        addon_prefs = context.user_preferences.addons["maszyna_t3d_export"].preferences
        self.report({'INFO'}, (addon_prefs.root_path))
        return {"FINISHED"}


def menu_func_export(self, context):
    self.layout.operator(ExportT3D.bl_idname, text="MaSzyna Text Model (.t3d)")


def register():
    bpy.utils.register_module(__name__)
    bpy.types.INFO_MT_file_export.append(menu_func_export)


def unregister():
    bpy.utils.unregister_module(__name__)
    bpy.types.INFO_MT_file_export.remove(menu_func_export)


if __name__ == '__main__':
    register()
